<template>
  <div class="searchbar-container">
    <BlSearchbar
      v-model.trim="searchValue"
      placeholder="搜索姓名/身份证号"
      @search="handleSearch"
      @change="handleSearch"
    ></BlSearchbar>
  </div>
  <InfiniteLoading scrollViewClassName="common-infinite-scroll-list" v-bind="infiniteLoadingProps">
    <template #renderItem="{ item }">
      <FlexJobCard :showFooterLeft="false">
        <template #footerRight>
          <nut-button type="primary">安排</nut-button>
          <!-- <div class="batch-task-card-status">已安排</div> -->
        </template>
      </FlexJobCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import Taro from '@tarojs/taro';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import * as orderServices from '@12333/services/api/Order';
import _ from 'lodash';
import { trim } from '@12333/utils';
import { FlexJobCard } from '@12333/components';

defineOptions({
  name: 'InnerPage',
});

const searchValue = ref('');

const queryState = reactive({
  searchValueTrim: '',
});

const handleSearch = _.debounce(function () {
  queryState.searchValueTrim = trim(searchValue.value);
}, 300);

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.FrontOrderListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [{ property: 'lastShelfTime', order: OrderInputType.Desc }],
      },
    };

    return orderServices.getFrontOrderList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['orderServices/getFrontOrderList', queryState],
  }
);
</script>

<style lang="scss">
@import '@/styles/common.scss';

.searchbar-container {
  padding: boleGetCssVar('size', 'body-padding-h');
  padding-top: 0;
}

.batchTaskList-page-wrapper {
  .batch-task-card-status {
    line-height: 52px;
    color: boleGetCssVar('text-color', 'primary');
    font-size: 24px;
  }
}
</style>
